#[non_exhaustive]pub enum RecipeResolveError {
Missing {
endpoint: RecipeEndpoint,
name: String,
},
Invalid {
endpoint: RecipeEndpoint,
name: String,
reason: &'static str,
},
}Expand description
Failure while resolving one of a recipe’s required named endpoints.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Missing
The required endpoint was absent from the bound runtime.
Fields

endpoint: RecipeEndpointRequired endpoint category.
Invalid
A named endpoint exists but does not satisfy the requested contract.