ScenarioError

Enum ScenarioError 

#[non_exhaustive]
pub enum ScenarioError { Recipe(RecipeError), Handle(HandleError), MissingSignal { path: String, tick: u64, }, UnexpectedSignal { path: String, expected: Signal, actual: Signal, tick: u64, }, ExpectedTruthy { path: String, actual: Signal, tick: u64, }, UnexpectedEmits { command: String, expected: usize, actual: usize, tick: u64, }, }
Failure while driving or asserting a typed crate::Scenario.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Recipe(RecipeError)

Binding the recipe for the scenario failed.



Handle(HandleError)

A typed frame write or endpoint lookup used an invalid runtime handle.



MissingSignal

An expectation ran before the scenario had produced a sample for the path.

Fields

path: String

Host path selected through the recipe’s typed ports.

tick: u64

Scenario frame that was being inspected.



UnexpectedSignal

A signal sample did not have the expected value.

Fields

path: String

Host path selected through the recipe’s typed ports.

expected: Signal

Expected sample.

actual: Signal

Sample produced by the runtime.

tick: u64

Scenario frame that produced the sample.



ExpectedTruthy

A signal sample was present but falsey.

Fields

path: String

Host path selected through the recipe’s typed ports.

actual: Signal

Falsey sample produced by the runtime.

tick: u64

Scenario frame that produced the sample.



UnexpectedEmits

A command was emitted a different number of times than expected.

Fields

command: String

Command selected through the recipe’s typed ports.

expected: usize

Expected number of emits in the current frame.

actual: usize

Actual number of emits in the current frame.

tick: u64

Scenario frame that produced the emits.