RecipeInstance

Struct RecipeInstance 

pub struct RecipeInstance<R: Recipe> { /* private fields */ }
One bound Recipe with its runtime and typed resolved ports.

Implementations

Source

impl<R: Recipe> RecipeInstance<R>

pub fn runtime(&self) -> &Runtime

Borrow the executable runtime for advanced host integration.

pub fn runtime_mut(&mut self) -> &mut Runtime

Mutably borrow the executable runtime for frame setup and loom.

pub fn ports(&self) -> &R::Ports

Borrow the recipe’s typed, runtime-owned ports.

pub fn into_parts(self) -> (Runtime, R::Ports)

Split this instance into its runtime and typed ports.