HandleError

Enum HandleError 

#[non_exhaustive]
pub enum HandleError { ForeignRuntime { handle: &'static str, }, InvalidSense { sense: SenseId, }, InvalidHostPath { path: HostPathId, }, InvalidCommand { cmd: CmdId, }, InvalidKnot { knot: KnotHandle, }, InvalidPort { knot: KnotHandle, port: PortSlot, }, DomainValue { sense: SenseId, domain: SignalDomain, }, }
Failure caused by using a dense handle with the wrong runtime or port.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ForeignRuntime

Dense handle belongs to a different Runtime.

Fields

handle: &'static str

Human-readable handle kind ("sense", "host path", …).



InvalidSense

SenseId is out of range or does not reference a SignalIn knot.

Fields

sense: SenseId

Rejected dense sense handle.



InvalidHostPath

HostPathId is out of range for this runtime.

Fields

path: HostPathId

Rejected dense host-path handle.



InvalidCommand

CmdId is out of range for this runtime.

Fields

cmd: CmdId

Rejected dense command handle.



InvalidKnot

KnotHandle is out of range for this runtime.

Fields

knot: KnotHandle

Rejected dense knot handle.



InvalidPort

PortSlot is invalid for the given knot in this runtime.

Fields

knot: KnotHandle

Knot that owns the rejected port slot.

port: PortSlot

Rejected catalog port slot.



DomainValue

A host-authored sense value violates its declared signal domain.

Fields

sense: SenseId

Sense port that rejected the write.

domain: SignalDomain

Declared domain for that SignalIn knot.