pub struct RecipeInstance<R: Recipe> { /* private fields */ }Expand description
One bound Recipe with its runtime and typed resolved ports.
Implementations
Sourceimpl<R: Recipe> RecipeInstance<R>
impl<R: Recipe> RecipeInstance<R>
Sourcepub fn runtime_mut(&mut self) -> &mut Runtime
pub fn runtime_mut(&mut self) -> &mut Runtime
Mutably borrow the executable runtime for frame setup and loom.
Sourcepub fn into_parts(self) -> (Runtime, R::Ports)
pub fn into_parts(self) -> (Runtime, R::Ports)
Split this instance into its runtime and typed ports.